"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/stripe.ts
var stripe_exports = {};
__export(stripe_exports, {
  createTKTRStripeHandler: () => createTKTRStripeHandler
});
module.exports = __toCommonJS(stripe_exports);
var import_core = require("@tktr/core");

// src/index.ts
var eventLists = ["purchase", "purchase.failed", "purchase.cancelled", "purchase.success"];
function getBaseUrl(origin, path) {
  return `${origin}/api/tktr/${path}`;
}

// src/stripe.ts
async function createTKTRStripeHandler({ stripe, store, items }) {
  return async (request) => {
    const routeMatcher = /\/api\/tktr\/(.*)/;
    const url = new URL(request.url);
    const route = url.pathname.match(routeMatcher)[1];
    const origin = url.origin;
    const [_command, ...params] = route.split("/");
    let command;
    if ((command = eventLists.find((k) => k === _command)) === void 0) {
      return new import_core.TKTRError("INVALID_COMMAND").toResponse();
    }
    switch (command) {
      case "purchase": {
        const [_item, ...rest] = params;
        let item;
        if ((item = items.find((i) => i.id === _item)) === void 0) {
          return new import_core.TKTRError("INVALID_ITEM").toResponse();
        }
        const success_url = `${getBaseUrl(origin, "purchase.success")}/${item.id}/{CHECKOUT_SESSION_ID}`;
        const cancel_url = `${getBaseUrl(origin, "purchase.cancelled")}/${item.id}`;
        const search = new URLSearchParams();
        const redirectBack = request.headers.get("referer");
        search.set("continue", redirectBack);
        const { url: url2 } = await stripe.checkout.sessions.create({
          currency: "usd",
          line_items: [
            {
              quantity: 1,
              price_data: {
                currency: store.currency,
                product_data: {
                  name: item.name
                },
                unit_amount: (0, import_core.formatAmountForStripe)(item.price, store.currency),
                recurring: item.recurring
              }
            }
          ],
          mode: "payment",
          ui_mode: "hosted",
          success_url: `${success_url}?${search.toString()}`,
          cancel_url: `${cancel_url}?${search.toString()}`
        });
        if (!url2)
          return new import_core.TKTRError("CREATE_CHECKOUT_SESSION_FAILED").toResponse();
        return Response.redirect(url2, 303);
      }
      case "purchase.success": {
        const [_item, sessionId] = params;
        const item = items.find((i) => i.id === _item);
        if (!item)
          return new import_core.TKTRError("INVALID_ITEM").toResponse();
        const checkoutSession = await stripe.checkout.sessions.retrieve(sessionId, {
          expand: ["line_items", "payment_intent"]
        });
        const paymentIntent = checkoutSession.payment_intent;
        if (!paymentIntent)
          return new import_core.TKTRError("RETRIEVE_CHECKOUT_SESSION_FAILED").toResponse();
        const continueTo = url.searchParams.get("continue");
        return Response.redirect(
          continueTo,
          303
        );
      }
      case "purchase.cancelled": {
        const [_item] = params;
        const continueTo = url.searchParams.get("continue");
        return Response.redirect(
          continueTo,
          303
        );
      }
      default: {
        return new import_core.TKTRError("NOT_IMPLEMENTED").toResponse();
      }
    }
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  createTKTRStripeHandler
});
