import {
  eventLists,
  getBaseUrl
} from "./chunk-O6NZCYOH.mjs";

// src/stripe.ts
import { formatAmountForStripe, TKTRError } from "@tktr/core";
async function createTKTRStripeHandler({ stripe, store, items }) {
  return async (request) => {
    const routeMatcher = /\/api\/tktr\/(.*)/;
    const url = new URL(request.url);
    const route = url.pathname.match(routeMatcher)[1];
    const origin = url.origin;
    const [_command, ...params] = route.split("/");
    let command;
    if ((command = eventLists.find((k) => k === _command)) === void 0) {
      return new TKTRError("INVALID_COMMAND").toResponse();
    }
    switch (command) {
      case "purchase": {
        const [_item, ...rest] = params;
        let item;
        if ((item = items.find((i) => i.id === _item)) === void 0) {
          return new TKTRError("INVALID_ITEM").toResponse();
        }
        const success_url = `${getBaseUrl(origin, "purchase.success")}/${item.id}/{CHECKOUT_SESSION_ID}`;
        const cancel_url = `${getBaseUrl(origin, "purchase.cancelled")}/${item.id}`;
        const search = new URLSearchParams();
        const redirectBack = request.headers.get("referer");
        search.set("continue", redirectBack);
        const { url: url2 } = await stripe.checkout.sessions.create({
          currency: "usd",
          line_items: [
            {
              quantity: 1,
              price_data: {
                currency: store.currency,
                product_data: {
                  name: item.name
                },
                unit_amount: formatAmountForStripe(item.price, store.currency),
                recurring: item.recurring
              }
            }
          ],
          mode: "payment",
          ui_mode: "hosted",
          success_url: `${success_url}?${search.toString()}`,
          cancel_url: `${cancel_url}?${search.toString()}`
        });
        if (!url2)
          return new TKTRError("CREATE_CHECKOUT_SESSION_FAILED").toResponse();
        return Response.redirect(url2, 303);
      }
      case "purchase.success": {
        const [_item, sessionId] = params;
        const item = items.find((i) => i.id === _item);
        if (!item)
          return new TKTRError("INVALID_ITEM").toResponse();
        const checkoutSession = await stripe.checkout.sessions.retrieve(sessionId, {
          expand: ["line_items", "payment_intent"]
        });
        const paymentIntent = checkoutSession.payment_intent;
        if (!paymentIntent)
          return new TKTRError("RETRIEVE_CHECKOUT_SESSION_FAILED").toResponse();
        const continueTo = url.searchParams.get("continue");
        return Response.redirect(
          continueTo,
          303
        );
      }
      case "purchase.cancelled": {
        const [_item] = params;
        const continueTo = url.searchParams.get("continue");
        return Response.redirect(
          continueTo,
          303
        );
      }
      default: {
        return new TKTRError("NOT_IMPLEMENTED").toResponse();
      }
    }
  };
}
export {
  createTKTRStripeHandler
};
